clear all
close all

dt=0.01; 
fs=1/dt;

disp(sprintf('Sampling rate = %d' ,fs))

t=0:dt:100-dt;
n=size(t,2);

dF = 1/(dt*n);                     
f = -1/(2*dt):dF:1/(2*dt)-dF;  

F1=sin(2*pi*70*t)+sin(2*pi*15*t);
F2=sin(2*pi*80*t);
F3=sin(2*pi*90*t);

FF1=fftshift(fft(F1));
FF2=fftshift(fft(F2));
FF3=fftshift(fft(F3));

DSR=20;
Dfs=fs/DSR;

disp(sprintf('Downsampling factor = %d' ,DSR))
disp(sprintf('Downsampled sampling rate = %d' ,Dfs))

cutoff=0.8/DSR;

[b,a] = butter(10,cutoff); 
[c,d] = freqz(b,a,1000,fs);

cutoffx=[cutoff*fs/2,cutoff*fs/2];
cutoffy=[0 1.2];

figure
hold on
plot(d(1:round(length(d)/2)),abs(c(1:round(length(d)/2))))
plot(cutoffx,cutoffy,'-')
grid on
xlim([0 50]);
legend('Frequency response','Lowpass cutoff frequency')
xlabel('f [hz]')
ylabel('H(f)')
title('Filter')
hold off

F11=filtfilt(b,a,F1);
F22=filtfilt(b,a,F2);
F33=filtfilt(b,a,F3);

F4=F11(1:DSR:end);
F5=F22(1:DSR:end);
F6=F33(1:DSR:end);
FF4=fftshift(fft(F4));
FF5=fftshift(fft(F5));
FF6=fftshift(fft(F6));

F7=F1(1:DSR:end);
F8=F2(1:DSR:end);
F9=F3(1:DSR:end);
FF7=fftshift(fft(F7));
FF8=fftshift(fft(F8));
FF9=fftshift(fft(F9));

Nyquistx=[25 25];
Nyquisty=[0 0.025];

figure;
hold on
plot(f,abs(FF1)/n);
plot(f,abs(FF2)/n);
plot(f,abs(FF3)/n);
legend('70Hz+15Hz','80Hz','90Hz')
xlim([0 100])
xlabel('Frequency (Hz)');
title('Raw data');
hold off

fs_new=fs/DSR;
df_RS=(fs_new)*DSR/(n-1);
fs_rs=-fs_new/2:df_RS:fs_new/2;
n2=n/DSR;

figure;
hold on
plot(fs_rs,abs(FF4)/n);
plot(fs_rs,abs(FF5)/n);
plot(fs_rs,abs(FF6)/n);
plot(Nyquistx,Nyquisty,'-');
xlim([0 100])
legend('70Hz+15Hz downsampled','80Hz downsampled','90Hz downsampled','Nyquist Frequency')
xlabel('Frequency (Hz)');
title('Downsampled filtered signal');
hold off

figure;
hold on
plot(fs_rs,abs(FF7)/n);
plot(fs_rs,abs(FF8)/n);
plot(fs_rs,abs(FF9)/n);
plot(Nyquistx,Nyquisty,'-');
xlim([0 100])
legend('70Hz+15Hz downsampled','80Hz downsampled','90Hz downsampled','Nyquist Frequency')
xlabel('Frequency (Hz)');
title('Downsampled unfiltered signal');
hold off
